check := function(group, c, k)
  local g0, i, g2, x1, x2, g1;

  g0 := Representative(c);
  i := Filtered(c, x->x*g0=g0*x);

  for g1 in i do
    if not g0=g1 then
      g2 := Inverse(g1)*(g0^k);
      x1 := RepresentativeAction(group, g1, g0);
      x2 := Inverse(x1);
      if g2 in i and x2*g0*Inverse(x2)=g2 then
        return [g0,g1,g2,x1,x2];
      fi;
    fi;
  od;
  return [];
end;

LoadPackage("atlasrep");

LogTo("fgv.log");

gr := AtlasGroup("M20");
cc := ConjugacyClasses(gr);
ct := CharacterTable(gr);

Print("Group:\n");
Print(gr,"\n");
Print("Conjugacy classes:\n");
Print(ClassNames(ct),"\n");

for n in [ct.2a, ct.2b, ct.4a, ct.4b, ct.4c] do
  c := cc[n];
  g := Representative(c);

  Print("Conjugacy class: ", ClassNames(ct)[n],"\n");

  gen := check(gr, c, 3);
  Print("g1=", gen[1], "\n");
  Print("g2=", gen[2], "\n");
  Print("g3=", gen[3], "\n");
  Print("x1=", gen[4], "\n");
  Print("x2=", gen[5], "\n");
  Print("--\n");
#  sub := Subgroup(gr, gen);
#  Print(Size(sub),"\n");
#  Print(IdGroup(sub),"\n");
#  Print(StructureDescription(sub),"\n");

od;

ct_m21 := CharacterTable("L3(4)");

Print("Possible Fusions from M20 into M21:\n");
Print("Clases of M20: ", ClassNames(ct), "\n");
Print("Clases of M21: ", ClassNames(ct_m21), "\n");

for fusion in PossibleClassFusions(ct, ct_m21) do
  for i in [1..Size(fusion)] do
    Print(ClassNames(ct)[i], "-->", ClassNames(ct_m21)[fusion[i]], "\n");
  od;
  Print("==\n");
od;


